"use strict";
var _a, _b;
Object.defineProperty(exports, "__esModule", { value: true });
exports.MetricType = exports.Tracker = void 0;
const doi_1 = require("./lib/doi");
const tracker_1 = require("./lib/tracker");
Object.defineProperty(exports, "Tracker", { enumerable: true, get: function () { return tracker_1.Tracker; } });
Object.defineProperty(exports, "MetricType", { enumerable: true, get: function () { return tracker_1.MetricType; } });
// Logic to handle being included in a page (DOM access)
if (typeof window === "object") {
    var scriptEl = document.currentScript;
    if (scriptEl) {
        // Find the DOI
        let doi = "";
        // Get DOI from the dataset tag always as preferred
        doi = scriptEl.dataset.doi || "";
        if (doi == "") {
            // Look for DOI in schema.org element
            // Then in DC metadata
            // Finally check the URL path
            var element;
            if (element = (_a = document.querySelector('script[type="application/ld+json"]')) === null || _a === void 0 ? void 0 : _a.innerHTML) {
                doi = (0, doi_1.doi_from_schema_org_json)(element);
            }
            else if (element = (_b = document.querySelector('meta[name="DC.Identifier"]')) === null || _b === void 0 ? void 0 : _b.getAttribute('content')) {
                doi = (0, doi_1.doi_from_url)(element);
            }
            else {
                doi = (0, doi_1.doi_from_url_path)(window.location.href);
            }
        }
        if (doi == "") {
            console.log("[DataCiteTracker] You need to add the DOI name into your tracking snippet");
        }
        else {
            let repoid = scriptEl.dataset.repoid || location.hostname;
            let metric = scriptEl.dataset.metric || "view";
            let auto_track = JSON.parse(scriptEl.dataset.autotrack || "true");
            let localhost = JSON.parse(scriptEl.dataset.localhost || "false");
            let endpoint = scriptEl.dataset.endpoint || "https://analytics.datacite.org";
            // Setup the tracker
            const { trackMetric } = (0, tracker_1.Tracker)({
                repoId: repoid,
                trackLocalhost: localhost,
                apiHost: endpoint,
            });
            // Default usage tracking
            if (auto_track) {
                switch (metric) {
                    case "view":
                        trackMetric(tracker_1.MetricType.View, { doi: doi });
                        break;
                    case "download":
                        trackMetric(tracker_1.MetricType.Download, { doi: doi });
                        break;
                    default:
                        console.log(`[DataCiteTracker] Unknown metric type ${metric}`);
                }
            }
        }
    }
}
Object.assign(module.exports, tracker_1.Tracker, tracker_1.MetricType);
//# sourceMappingURL=index.js.map