"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validate_doi = exports.doi_from_schema_org_json = exports.doi_from_url_path = exports.doi_from_url = void 0;
function doi_from_url(url) {
    // Derived from https://github.com/datacite/bolognese/blob/0f3b1d1f3830399a24e69d0f2262e7ff7c0190c9/lib/bolognese/doi_utils.rb
    var ret = "";
    var doi;
    if (url &&
        (doi = url.match(/^(?:(http|https):\/(\/)?(dx\.)?(doi.org|handle.stage.datacite.org|handle.test.datacite.org)\/)?(doi:)?(10\.\d{4,5}\/.+)$/)) &&
        (doi = doi[6]) &&
        (doi = decodeURIComponent(doi).toLowerCase()) &&
        (doi = doi.replace(/\/+$/, ""))) {
        ret = doi;
    }
    return ret;
}
exports.doi_from_url = doi_from_url;
function doi_from_url_path(url) {
    var ret = "";
    var path, text, doi, url_t;
    if (url &&
        (url = decodeURIComponent(url)) &&
        (url_t = new URL(url)) &&
        (path = url_t.pathname + url_t.search) &&
        (text = path.match(/(10\.\d{4,5}\/.+)$/)) &&
        (doi = text[1].replace(/\/$/, '').toLowerCase()) &&
        (validate_doi(doi))) {
        ret = doi;
    }
    return ret;
}
exports.doi_from_url_path = doi_from_url_path;
function doi_from_schema_org_json(schema_org_json) {
    var ret = "";
    var identifiers;
    var json, url, doi;
    if ((json = JSON.parse(schema_org_json)) &&
        (('@context' in json) && (json['@context'] == 'http://schema.org' || json['@context'] == 'https://schema.org'))) {
        if (('@id' in json) && (url = json['@id']) &&
            (doi = doi_from_url(url))) {
            ret = doi;
        }
        else if (('identifier' in json) && json.identifier) {
            identifiers = [];
            if (typeof json.identifier == 'string') {
                identifiers[0] = json.identifier;
            }
            else if (Array.isArray(json.identifier)) {
                identifiers = json.identifier;
            }
            identifiers.every(url => {
                if (url && (doi = doi_from_url(url))) {
                    ret = doi;
                    return false;
                }
                else {
                    return true;
                }
            });
        }
    }
    return ret;
}
exports.doi_from_schema_org_json = doi_from_schema_org_json;
function validate_doi(doi) {
    var ret = "";
    var doi_r;
    if (doi &&
        (doi_r = doi.match(/^(10\.\d{4,5}\/.+)$/)) &&
        (doi_r[1])) {
        ret = doi_r[1];
    }
    return ret;
}
exports.validate_doi = validate_doi;
//# sourceMappingURL=doi.js.map